@@ -1,5 +1,5 @@
-import sys, os, re
-from django.http import HttpResponse
+import sys, re
+from django.http import HttpResponse, Http404
 import helptools
 
 formats = {
@@ -19,15 +19,17 @@ def get_file(name, mime):
             if i[len(i)-13:len(i)] == 'site-packages':
                 response = read_and_close(f'{i}/helptools/files/{name}')
     get_file.only_text = response
-    response = HttpResponse(response)
-    response._headers['content-type'] = ('Content-Type', f'{mime}; charset=utf-8')
+    response = HttpResponse(response, content_type=f'{mime}; charset=utf-8')
     return response
 
 def file(request, file_name):
-    if file_name.replace('docs', '') != file_name: return None
-    file_format = re.search('.+\.',file_name).group()
-    file_format = file_name.replace(file_format, '')
-    return get_file(file_name, formats[file_format])
+    if file_name.replace('docs', '') != file_name: raise Http404
+    try:
+        file_format = re.search('.+\.',file_name).group()
+        file_format = file_name.replace(file_format, '')
+        return get_file(file_name, formats[file_format])
+    except:
+        raise Http404
 
 def docs(request):
     if helptools.show_docs:
@@ -44,3 +46,5 @@ def docs(request):
         file = file.replace('{{body}}', get_file.only_text)
 
         return HttpResponse(file)
+    else:
+        raise Http404
